@@ -92,7 +92,10 @@ def validate_function_name(function_name, verbose=True):
     supported_services = ["prediction", "training"]
     supported_environments = ["dev", "test", "prod"]
     try:
-        model, service, environment = function_name.split("-")
+        if len(splitted_function_name := function_name.split("-")) > 3: 
+            model, service, environment, version = splitted_function_name
+        else:
+            model, service, environment = splitted_function_name
     except ValueError:
         if verbose:
             m = f"Expected function name format: 'model-service-environment'"
@@ -135,7 +138,7 @@ def delete_function(function_name, confirm=True):
         client = global_client["functions"]
         try:
             client.functions.delete(external_id=function_name)
-            logging.debug(f"Deleted function with {function_name=}")
+            logging.info(f"Deleted function with external-id {function_name=}")
         except CogniteNotFoundError:
             logging.error(f"Couldn't find function with '{function_name=}'")
 
@@ -165,10 +168,16 @@ def create_function_from_folder(
       - secrets (Dict[str, Any]): api keys or similar that should be passed to the function
     """
     client = global_client["functions"]
+
     try:
         client.functions.delete(external_id=function_name)
-        logging.debug(f"Deleted function {human_readable_name} with external id {function_name}")
+        logging.info(
+            f"Function {human_readable_name} with external id {function_name} already exist and will be overwritten"
+        )
     except CogniteNotFoundError:
+        logging.info(
+            f"Function {human_readable_name} with external id {function_name} does not already exist"
+        )
         pass
     
     function = client.functions.create( 
@@ -182,10 +191,12 @@ def create_function_from_folder(
         secrets=secrets,
         env_vars=env_vars
     )
-    logging.debug(
+    logging.info(
         f"Created function {human_readable_name} with external id {function_name}: {folder=}, {handler_path=}, {env_vars=}"
     )
-
+    logging.info(
+        f"Starting deployment of function {human_readable_name} with external id {function_name}"
+    )
     return function
 
 
@@ -194,6 +205,7 @@ def create_function_from_file(
     function_name, 
     file_id, 
     description,
+    metadata,
     owner,
     secrets={}
 ):
@@ -217,6 +229,7 @@ def create_function_from_file(
         file_id=file_id,
         external_id=function_name,
         description=description,
+        metadata=metadata,
         owner=owner,
         secrets=secrets,
         env_vars=env_vars
@@ -269,6 +282,7 @@ def deploy_function(
       - folder: path where the source code is located
       - handler_path: path to the handler file
       - secrets: api keys or similar that should be passed to the function
+      - info: dictionary containig info for a specifig service, as specified in the setting
     """
     try:
         description = info["description"]
@@ -304,6 +318,7 @@ def redeploy_function(
     function_name,
     file_id,
     description,
+    metadata,
     owner,
     secrets=api_keys
 ):
@@ -311,9 +326,11 @@ def redeploy_function(
     Deploys a Cognite function from a folder. 
 
     Inputs:
-      - function_name: name of the function to create
-      - file_id: (int) the id for the function file in CDF Files
-      - owner: (string) the function's owner's email
+      - function_name (str): name of the function to create
+      - file_id (int): the id for the function file in CDF Files
+      - owner (str): the function's owner's email
+      - description (str): function description
+      - metadata (Dict[str, str]): dictionary containing function metadata
       - secrets: (optional) api keys or similar that should be passed to the
         function
     """
@@ -323,6 +340,7 @@ def redeploy_function(
         function_name, 
         file_id, 
         description,
+        metadata,
         owner,
         secrets
     )
@@ -365,7 +383,7 @@ def call_function(function_name, data):
     """
     client = global_client["functions"]
     function = client.functions.retrieve(external_id=function_name)
-    logging.debug(f"Retrieved function {function_name}")
+    logging.info(f"Retrieved function with external-id {function_name} from CDF")
     call_complete = False
     t_start = time.process_time()
     while not call_complete:
@@ -374,10 +392,11 @@ def call_function(function_name, data):
             call_complete = True
         except CogniteAPIError:
             logging.warning(f"Cognite API error, try again")
-    logging.debug(f"Called function ({call.id=})")
+    logging.info(f"Called function ({call.id=})")
     response = call.get_response()
-    t_proc = time.process_time() - t_start
-    logging.debug(f"Call complete ({call.id=}, {t_proc=}): {response=}")
+    status=response["status"]
+    duration = time.process_time() - t_start
+    logging.info(f"Function call complete ({call.id=}, {duration=}): {status=}")
     return response
 
 def call_function_process_wrapper(function_name, data):
@@ -413,7 +432,7 @@ def test_function(function_name, data):
     Call a function with data and verify that the response's 
     status is 'ok'
     """
-    logging.debug(f"Test function {function_name}")
+    logging.info(f"Testing function {function_name}")
     if not validate_function_name(function_name):
         raise ValueError()
     output = call_function(function_name, data)
@@ -432,12 +451,12 @@ def wait_function_status(function, status=["Ready", "Failed"]):
     max_api_errors_base = 5
     max_api_errors = max_api_errors_base
     
-    logging.debug(f"Wait for function to be ready or to fail")
+    logging.info(f"Wait for function to be ready or to fail")
     while not (function.status in status):
         try:
             time.sleep(polling_wait_seconds)
             function.update()
-            logging.debug(f"{function.status=}")
+            logging.info(f"{function.status=}")
             polling_wait_seconds = polling_wait_seconds_base
             max_api_errors = max_api_errors_base
         except CogniteAPIError as e:
