@@ -14,6 +14,7 @@ from pathlib import Path
 import akerbp.mlops.model_manager as mm
 from akerbp.mlops.deployment import helpers, platforms
 from akerbp.mlops.core import logger, config
+from akerbp.mlops.cdf import helpers as cdf
 logging=logger.get_logger(name='mlops_deployment')
 
 
@@ -38,9 +39,10 @@ def deploy_model(model_settings, platform_methods=platform_methods):
         service_name = config.envs.service_name
         deployment_folder = helpers.deployment_folder_path(c.model_name)
         function_name = f"{c.model_name}-{service_name}-{env}"
+        human_readable_function_name = c.human_friendly_model_name
 
         logging.debug(" ")
-        logging.info(f"Deploy model {c.model_name}")
+        logging.info(f"Starting deployment of model {c.human_friendly_model_name} with external id {function_name}")
 
         if (service_name == 'prediction') and c.artifact_folder:
             mm.set_active_dataset(c.dataset)
@@ -66,13 +68,31 @@ def deploy_model(model_settings, platform_methods=platform_methods):
         else:
             logging.warning("Model test file is missing! Didn't run tests")
 
-        logging.info(f"Deploy {function_name} to {c.platform}")
+        if c.platform == "cdf": # For now this will always be the case. #TODO:  
+            if len(splitted_external_id := function_name.split("-")) > 3: 
+                latest_model_version = splitted_external_id[-1]
+                env = splitted_external_id[-2]
+            else: 
+                env = splitted_external_id[-1]
+            model_name = splitted_external_id[0]
+
+            artifact_external_id = model_name + "/" + env 
+            artifact_versions = cdf.query_file_versions(directory_prefix="/mlops", external_id_prefix=artifact_external_id)
+            if len(artifact_versions) == 0:
+                return f"Model {human_readable_function_name} failed to deploy to {env} because no artifacts were found. Please upload/promote artifacts or specify a correct model name and redeploy"
+            latest_artifact_version = artifact_versions.loc[artifact_versions.uploadedTime.argmax()].metadata["version"]
+            logging.info(f"Latest artifact version in {env} environment is {latest_artifact_version}")
+            external_id = function_name + "-" + str(latest_artifact_version)
+        else: 
+            external_id = function_name 
+
+        logging.info(f"Deploying function {human_readable_function_name} with external id {external_id} to {c.platform}")
         deploy_function, test_function = platform_methods[c.platform]
-        deploy_function(function_name, info=c.info[service_name])
+        deploy_function(human_readable_function_name, external_id, info=c.info[service_name])
         
         if c.test_file:
             logging.info("Make a test call")
-            test_function(function_name, model_input)
+            test_function(external_id, model_input) 
         else:
             logging.warning("No test file was set up. End-to-end test skipped!")
     
@@ -99,7 +119,7 @@ def deploy(project_settings):
         status = deploy_model(c)
         if status != "OK":
             logging.error(status)
-            failed_models[c.model_name] = status
+            failed_models[c.human_friendly_model_name] = status
         
         logging.debug(f"cd ..")
         os.chdir(cwd_path)
